
# Slot: negatively regulated by




URI: [biolink:negatively_regulated_by](https://w3id.org/biolink/vocab/negatively_regulated_by)


## Domain and Range

[PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md) &#8594;  <sub>0..1</sub> [PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md)

## Parents

 *  is_a: [regulated by](regulated_by.md)

## Children


## Used by

